@@ -202,7 +202,7 @@ public class DeferrerServlet extends HttpServlet {
                     }
                 }
             }
-        } catch (final Exception e) {
+        } catch (Exception e) {
             final Logger logger = org.slf4j.LoggerFactory.getLogger(DeferrerServlet.class);
             logger.debug("", e);
         }
@@ -226,7 +226,7 @@ public class DeferrerServlet extends HttpServlet {
             if (null != query) {
                 return parseQueryString(query);
             }
-        } catch (final Exception e) {
+        } catch (Exception e) {
             final Logger logger = org.slf4j.LoggerFactory.getLogger(DeferrerServlet.class);
             logger.debug("", e);
         }
