@@ -84,27 +84,17 @@ public final class DropboxOAuthActivator extends AbstractOAuthActivator {
             // Clear service registry
             DropboxOAuthServices.setServices(null);
             super.stopBundle();
-        } catch (final Exception e) {
+        } catch (Exception e) {
             org.slf4j.LoggerFactory.getLogger(DropboxOAuthActivator.class).error("", e);
             throw e;
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.oauth.common.osgi.AbstractOAuthActivator#getOAuthServiceMetaData()
-     */
     @Override
     protected OAuthServiceMetaData getOAuthServiceMetaData() {
         return new DropboxOAuthServiceMetaData(this);
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.oauth.common.osgi.AbstractOAuthActivator#getScopes()
-     */
     @Override
     protected OAuthScope[] getScopes() {
         return DropboxOAuthScope.values();
