@@ -59,7 +59,6 @@ import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.config.cascade.ConfigViews;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.oauth.HostInfo;
 import com.openexchange.oauth.OAuthConfigurationProperty;
 import com.openexchange.oauth.OAuthInteraction;
@@ -69,6 +68,7 @@ import com.openexchange.oauth.impl.services.Services;
 import com.openexchange.oauth.scope.OAuthScope;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.session.Session;
+import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 
 /**
@@ -333,7 +333,7 @@ public abstract class AbstractOAuthServiceMetaData implements OAuthServiceMetaDa
     protected static String urlEncode(final String s) {
         try {
             return URLEncoder.encode(s, "ISO-8859-1");
-        } catch (final UnsupportedEncodingException e) {
+        } catch (UnsupportedEncodingException e) {
             return s;
         }
     }
