@@ -49,6 +49,7 @@
 
 package com.openexchange.oauth.impl.internal;
 
+import static com.openexchange.database.Databases.autocommit;
 import static com.openexchange.database.Databases.closeSQLStuff;
 import static com.openexchange.database.Databases.rollback;
 import static com.openexchange.database.Databases.startTransaction;
@@ -129,11 +130,6 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         this.contextService = contextService;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#createAccount(com.openexchange.session.Session, com.openexchange.oauth.OAuthAccount)
-     */
     @Override
     public int storeAccount(Session session, OAuthAccount account) throws OXException {
         int contextId = session.getContextId();
@@ -153,18 +149,13 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         return account.getId();
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#getAccount(com.openexchange.session.Session, int)
-     */
     @Override
-    public OAuthAccount getAccount(Session session, int accountId) throws OXException {
+    public OAuthAccount getAccount(Session session, int accountId, boolean loadSecrets) throws OXException {
         Connection connection = (Connection) session.getParameter("__file.storage.delete.connection");
         try {
             if (connection != null && Databases.isInTransaction(connection)) {
                 // Given connection is already in transaction. Invoke & return immediately.
-                return getAccount(session, accountId, connection);
+                return getAccount(session, accountId, loadSecrets, connection);
             }
         } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
@@ -173,19 +164,14 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         final Context context = getContext(session.getContextId());
         connection = getConnection(true, context);
         try {
-            return getAccount(session, accountId, connection);
-        } catch (final SQLException e) {
+            return getAccount(session, accountId, loadSecrets, connection);
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             provider.releaseReadConnection(context, connection);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#deleteAccount(com.openexchange.session.Session, int)
-     */
     @Override
     public void deleteAccount(Session session, int accountId) throws OXException {
         int userId = session.getUserId();
@@ -215,11 +201,11 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             con.commit(); // COMMIT
             rollback = 2;
             LOG.info("Deleted OAuth account with id '{}' for user '{}' in context '{}'", I(accountId), I(userId), I(contextId));
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-        } catch (final OXException e) {
+        } catch (OXException e) {
             throw e;
-        } catch (final RuntimeException e) {
+        } catch (RuntimeException e) {
             throw OAuthExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } finally {
             Databases.closeSQLStuff(stmt);
@@ -233,11 +219,6 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#updateAccount(com.openexchange.session.Session, com.openexchange.oauth.OAuthAccount)
-     */
     @Override
     public void updateAccount(Session session, OAuthAccount account) throws OXException {
         // Crypt tokens
@@ -249,8 +230,8 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         int contextId = session.getContextId();
         int userId = session.getUserId();
         Context ctx = getContext(contextId);
-        Connection writeCon = getConnection(false, ctx);
         int rollback = 0;
+        Connection writeCon = getConnection(false, ctx);
         try {
             /*
              * Create UPDATE command
@@ -305,11 +286,6 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthAccountStorage#updateAccount(com.openexchange.session.Session, int, java.util.Map)
-     */
     @Override
     public void updateAccount(Session session, int accountId, Map<String, Object> arguments) throws OXException {
         final List<Setter> list = setterFrom(arguments, accountId);
@@ -330,29 +306,24 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         connection = getConnection(false, context);
         try {
             updateAccount(session, accountId, list, connection);
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             provider.releaseReadConnection(context, connection);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthAccountStorage#findByUserIdentity(com.openexchange.session.Session, java.lang.String, java.lang.String)
-     */
     @Override
-    public OAuthAccount findByUserIdentity(Session session, String userIdentity, String serviceId) throws OXException {
+    public OAuthAccount findByUserIdentity(Session session, String userIdentity, String serviceId, boolean loadSecrets) throws OXException {
         final SecretEncryptionService<PWUpdate> encryptionService = Services.getService(SecretEncryptionFactoryService.class).createService(this);
         final OAuthScopeRegistry scopeRegistry = Services.getService(OAuthScopeRegistry.class);
         int contextId = session.getContextId();
         int userId = session.getUserId();
         final Context context = getContext(contextId);
-        Connection connection = getConnection(true, context);
 
         PreparedStatement stmt = null;
         ResultSet rs = null;
+        Connection connection = getConnection(true, context);
         try {
             stmt = connection.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ? AND identity = ?");
             stmt.setInt(1, contextId);
@@ -369,15 +340,17 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             account.setId(accountId);
             String displayName = rs.getString(2);
             account.setDisplayName(displayName);
-            try {
-                account.setToken(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessToken", contextId, accountId)));
-                account.setSecret(encryptionService.decrypt(session, rs.getString(4), new PWUpdate("accessSecret", contextId, accountId)));
-            } catch (OXException e) {
-                if (CryptoErrorMessage.BadPassword.equals(e)) {
-                    throw e;
-                }
+            if (loadSecrets) {
+                try {
+                    account.setToken(decryptToken(rs.getString(3), accountId, session, encryptionService));
+                    account.setSecret(decryptSecret(rs.getString(4), accountId, session, encryptionService));
+                } catch (OXException e) {
+                    if (CryptoErrorMessage.BadPassword.equals(e)) {
+                        throw e;
+                    }
 
-                throw OAuthExceptionCodes.INVALID_ACCOUNT_EXTENDED.create(e.getCause(), displayName, I(accountId));
+                    throw OAuthExceptionCodes.INVALID_ACCOUNT_EXTENDED.create(e.getCause(), displayName, I(accountId));
+                }
             }
 
             account.setMetaData(registry.getService(rs.getString(5), userId, contextId));
@@ -386,7 +359,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             account.setEnabledScopes(enabledScopes);
             account.setUserIdentity(rs.getString(7));
             return account;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
@@ -394,21 +367,11 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthAccountStorage#hasUserIdentity(com.openexchange.session.Session, int, java.lang.String)
-     */
     @Override
     public boolean hasUserIdentity(Session session, int accountId, String serviceId) throws OXException {
         return Strings.isNotEmpty(getUserIdentity(session, serviceId, accountId, null));
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#getAccounts(com.openexchange.session.Session)
-     */
     @Override
     public List<OAuthAccount> getAccounts(Session session) throws OXException {
         final SecretEncryptionService<PWUpdate> encryptionService = Services.getService(SecretEncryptionFactoryService.class).createService(this);
@@ -416,10 +379,10 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         int userId = session.getUserId();
         int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(true, context);
+
         PreparedStatement stmt = null;
         ResultSet rs = null;
-
+        final Connection con = getConnection(true, context);
         try {
             stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, serviceId, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ?");
             stmt.setInt(1, contextId);
@@ -436,11 +399,11 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     account.setId(rs.getInt(1));
                     account.setDisplayName(rs.getString(2));
                     try {
-                        account.setToken(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessToken", contextId, account.getId())));
-                        account.setSecret(encryptionService.decrypt(session, rs.getString(4), new PWUpdate("accessSecret", contextId, account.getId())));
-                    } catch (final OXException e) {
+                        account.setToken(decryptToken(rs.getString(3), account.getId(), session, encryptionService));
+                        account.setSecret(decryptSecret(rs.getString(4), account.getId(), session, encryptionService));
+                    } catch (OXException e) {
                         // Log for debug purposes and ignore...
-                        LOG.debug("{}", e.getMessage(), e);
+                        LOG.debug("", e);
                     }
                     String scopes = rs.getString(6);
                     if (Strings.isNotEmpty(scopes)) {
@@ -449,7 +412,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     }
                     account.setUserIdentity(rs.getString(7));
                     accounts.add(account);
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     if (!OAuthExceptionCodes.UNKNOWN_OAUTH_SERVICE_META_DATA.equals(e)) {
                         throw e;
                     }
@@ -458,7 +421,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                 }
             } while (rs.next());
             return accounts;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             Databases.closeSQLStuff(rs, stmt);
@@ -466,11 +429,6 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.oauth.OAuthStorage#getAccounts(com.openexchange.session.Session, java.lang.String)
-     */
     @Override
     public List<OAuthAccount> getAccounts(Session session, String serviceMetaData) throws OXException {
         final SecretEncryptionService<PWUpdate> encryptionService = Services.getService(SecretEncryptionFactoryService.class).createService(this);
@@ -478,9 +436,10 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         int userId = session.getUserId();
         int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(true, context);
+
         PreparedStatement stmt = null;
         ResultSet rs = null;
+        final Connection con = getConnection(true, context);
         try {
             stmt = con.prepareStatement("SELECT id, displayName, accessToken, accessSecret, scope, identity FROM oauthAccounts WHERE cid = ? AND user = ? AND serviceId = ?");
             stmt.setInt(1, contextId);
@@ -498,9 +457,9 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     account.setId(rs.getInt(1));
                     account.setDisplayName(rs.getString(2));
                     try {
-                        account.setToken(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessToken", contextId, account.getId())));
-                        account.setSecret(encryptionService.decrypt(session, rs.getString(4), new PWUpdate("accessSecret", contextId, account.getId())));
-                    } catch (final OXException x) {
+                        account.setToken(decryptToken(rs.getString(3), account.getId(), session, encryptionService));
+                        account.setSecret(decryptSecret(rs.getString(4), account.getId(), session, encryptionService));
+                    } catch (OXException x) {
                         // Log for debug purposes and ignore...
                         LOG.debug("{}", x.getMessage(), x);
                     }
@@ -510,7 +469,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     account.setEnabledScopes(enabledScopes);
                     account.setUserIdentity(rs.getString(6));
                     accounts.add(account);
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     if (!OAuthExceptionCodes.UNKNOWN_OAUTH_SERVICE_META_DATA.equals(e)) {
                         throw e;
                     }
@@ -519,7 +478,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                 }
             } while (rs.next());
             return accounts;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
@@ -527,19 +486,14 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.secret.SecretEncryptionStrategy#update(java.lang.String, java.lang.Object)
-     */
     @Override
     public void update(String recrypted, PWUpdate customizationNote) throws OXException {
         final StringBuilder b = new StringBuilder();
         b.append("UPDATE oauthAccounts SET ").append(customizationNote.field).append("= ? WHERE cid = ? AND id = ?");
 
         final Context context = getContext(customizationNote.cid);
-        Connection con = null;
         PreparedStatement stmt = null;
+        Connection con = null;
         try {
             con = getConnection(false, context);
             stmt = con.prepareStatement(b.toString());
@@ -547,7 +501,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             stmt.setInt(2, customizationNote.cid);
             stmt.setInt(3, customizationNote.id);
             stmt.executeUpdate();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e.getMessage());
         } finally {
             Databases.closeSQLStuff(stmt);
@@ -555,23 +509,18 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.secret.recovery.EncryptedItemDetectorService#hasEncryptedItems(com.openexchange.tools.session.ServerSession)
-     */
     @Override
     public boolean hasEncryptedItems(ServerSession session) throws OXException {
         final int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(true, context);
         PreparedStatement stmt = null;
+        final Connection con = getConnection(true, context);
         try {
             stmt = con.prepareStatement("SELECT 1 FROM oauthAccounts WHERE cid = ? AND user = ? LIMIT 1");
             stmt.setInt(1, contextId);
             stmt.setInt(2, session.getUserId());
             return stmt.executeQuery().next();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(stmt);
@@ -579,19 +528,14 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.secret.recovery.SecretMigrator#migrate(java.lang.String, java.lang.String, com.openexchange.tools.session.ServerSession)
-     */
     @Override
     public void migrate(String oldSecret, String newSecret, ServerSession session) throws OXException {
         final CryptoService cryptoService = Services.getService(CryptoService.class);
         final int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(false, context);
         PreparedStatement stmt = null;
         ResultSet rs = null;
+        final Connection con = getConnection(false, context);
         try {
             stmt = con.prepareStatement("SELECT id, accessToken, accessSecret FROM oauthAccounts WHERE cid = ? AND user = ?");
             stmt.setInt(1, contextId);
@@ -612,7 +556,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     if (Strings.isNotEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, newSecret);
                     }
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     // Needs migration
                     final DefaultOAuthAccount account = new DefaultOAuthAccount();
                     account.setId(rs.getInt(1));
@@ -621,13 +565,14 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     accounts.add(account);
                 }
             } while (rs.next());
-            closeSQLStuff(rs, stmt);
             if (accounts.isEmpty()) {
                 return;
             }
             /*
              * Update
              */
+            closeSQLStuff(rs, stmt);
+            rs = null; stmt = null;
             stmt = con.prepareStatement("UPDATE oauthAccounts SET accessToken = ?, accessSecret = ? WHERE cid = ? AND user = ? AND id = ?");
             stmt.setInt(3, contextId);
             stmt.setInt(4, session.getUserId());
@@ -638,7 +583,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                 stmt.addBatch();
             }
             stmt.executeBatch();
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
@@ -646,20 +591,15 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.secret.recovery.EncryptedItemCleanUpService#cleanUpEncryptedItems(java.lang.String, com.openexchange.tools.session.ServerSession)
-     */
     @Override
     public void cleanUpEncryptedItems(String secret, ServerSession session) throws OXException {
         final CryptoService cryptoService = Services.getService(CryptoService.class);
         final int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(false, context);
         PreparedStatement stmt = null;
         ResultSet rs = null;
         Boolean committed = null;
+        final Connection con = getConnection(false, context);
         try {
             stmt = con.prepareStatement("SELECT id, accessToken, accessSecret FROM oauthAccounts WHERE cid = ? AND user = ?");
             stmt.setInt(1, contextId);
@@ -680,7 +620,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     if (Strings.isNotEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, secret);
                     }
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     // Clean-up
                     accounts.add(Integer.valueOf(rs.getInt(1)));
                 }
@@ -709,31 +649,29 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             stmt.executeBatch();
             con.commit();
             committed = Boolean.TRUE;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
-            if (null != committed && !committed.booleanValue()) {
-                rollback(con);
-            }
             closeSQLStuff(rs, stmt);
+            if (null != committed) {
+                if (!committed.booleanValue()) {
+                    rollback(con);
+                }
+                autocommit(con);
+            }
             provider.releaseWriteConnection(context, con);
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see com.openexchange.secret.recovery.EncryptedItemCleanUpService#removeUnrecoverableItems(java.lang.String, com.openexchange.tools.session.ServerSession)
-     */
     @Override
     public void removeUnrecoverableItems(String secret, ServerSession session) throws OXException {
         final CryptoService cryptoService = Services.getService(CryptoService.class);
         final int contextId = session.getContextId();
         final Context context = getContext(contextId);
-        final Connection con = getConnection(false, context);
         PreparedStatement stmt = null;
         ResultSet rs = null;
         Boolean committed = null;
+        final Connection con = getConnection(false, context);
         try {
             stmt = con.prepareStatement("SELECT id, accessToken, accessSecret FROM oauthAccounts WHERE cid = ? AND user = ?");
             stmt.setInt(1, contextId);
@@ -754,7 +692,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
                     if (Strings.isNotEmpty(accessSecret)) {
                         cryptoService.decrypt(accessSecret, secret);
                     }
-                } catch (final OXException e) {
+                } catch (OXException e) {
                     // Clean-up
                     accounts.add(Integer.valueOf(rs.getInt(1)));
                 }
@@ -781,13 +719,16 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             stmt.executeBatch();
             con.commit();
             committed = Boolean.TRUE;
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
-            if (null != committed && !committed.booleanValue()) {
-                rollback(con);
-            }
             closeSQLStuff(rs, stmt);
+            if (null != committed) {
+                if (!committed.booleanValue()) {
+                    rollback(con);
+                }
+                autocommit(con);
+            }
             provider.releaseWriteConnection(context, con);
         }
     }
@@ -804,16 +745,29 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      * @throws OXException
      */
     private void updateAccount(Session session, int accountId, List<Setter> list, Connection connection) throws SQLException, OXException {
-        final StringBuilder stmtBuilder = new StringBuilder(128).append("UPDATE oauthAccounts SET ");
-        final int size = list.size();
-        list.get(0).appendTo(stmtBuilder);
-        for (int i = 1; i < size; i++) {
-            stmtBuilder.append(", ");
-            list.get(i).appendTo(stmtBuilder);
+        // Compile SQL UPDATE statement
+        StringBuilder stmtBuilder = new StringBuilder(128);
+        {
+            stmtBuilder.append("UPDATE oauthAccounts SET ");
+            int size = list.size();
+            list.get(0).appendTo(stmtBuilder);
+            for (int i = 1; i < size; i++) {
+                stmtBuilder.append(", ");
+                list.get(i).appendTo(stmtBuilder);
+            }
+            stmtBuilder.append(" WHERE cid = ? AND user = ? and id = ?");
         }
+
         PreparedStatement stmt = null;
         try {
-            stmt = connection.prepareStatement(stmtBuilder.append(" WHERE cid = ? AND user = ? and id = ?").toString());
+            boolean signalReauthorization = false;
+            {
+                String sql = stmtBuilder.toString();
+                stmtBuilder = null;
+                stmt = connection.prepareStatement(sql);
+                signalReauthorization = sql.indexOf("accessToken") >= 0 || sql.indexOf("accessSecret") >= 0;
+            }
+
             int pos = 1;
             for (final Setter setter : list) {
                 pos = setter.set(pos, stmt);
@@ -827,6 +781,13 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             if (rows <= 0) {
                 throw OAuthExceptionCodes.ACCOUNT_NOT_FOUND.create(I(accountId), I(userId), I(contextId));
             }
+            /*
+             * Signal re-authorized event
+             */
+            if (signalReauthorization) {
+                Map<String, Object> properties = Collections.<String, Object> emptyMap();
+                ReauthorizeListenerRegistry.getInstance().onAfterOAuthAccountReauthorized(accountId, properties, userId, contextId, connection);
+            }
         } finally {
             closeSQLStuff(stmt);
         }
@@ -841,7 +802,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      * @throws SQLException
      * @throws OXException
      */
-    private OAuthAccount getAccount(Session session, int accountId, Connection connection) throws SQLException, OXException {
+    private OAuthAccount getAccount(Session session, int accountId, boolean loadSecrets, Connection connection) throws SQLException, OXException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -860,16 +821,18 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             account.setId(accountId);
             String displayName = rs.getString(1);
             account.setDisplayName(displayName);
-            try {
-                SecretEncryptionService<PWUpdate> encryptionService = Services.getService(SecretEncryptionFactoryService.class).createService(this);
-                account.setToken(encryptionService.decrypt(session, rs.getString(2), new PWUpdate("accessToken", contextId, accountId)));
-                account.setSecret(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessSecret", contextId, accountId)));
-            } catch (OXException e) {
-                if (CryptoErrorMessage.BadPassword.equals(e)) {
-                    throw e;
-                }
+            if (loadSecrets) {
+                try {
+                    SecretEncryptionService<PWUpdate> encryptionService = Services.getService(SecretEncryptionFactoryService.class).createService(this);
+                    account.setToken(decryptToken(rs.getString(2), accountId, session, encryptionService));
+                    account.setSecret(decryptSecret(rs.getString(3), accountId, session, encryptionService));
+                } catch (OXException e) {
+                    if (CryptoErrorMessage.BadPassword.equals(e)) {
+                        throw e;
+                    }
 
-                throw OAuthExceptionCodes.INVALID_ACCOUNT_EXTENDED.create(e.getCause(), displayName, I(accountId));
+                    throw OAuthExceptionCodes.INVALID_ACCOUNT_EXTENDED.create(e.getCause(), displayName, I(accountId));
+                }
             }
 
             if (Strings.isEmpty(account.getSecret())) {
@@ -898,14 +861,24 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
      * @throws OXException
      */
     private String getUserIdentity(Session session, String serviceId, int accountId, Connection connection) throws OXException {
+        if (connection != null) {
+            // Use given connection
+            return doGetUserIdentity(session, serviceId, accountId, connection);
+        }
+
+        // Acquire connection...
+        final Context context = getContext(session.getContextId());
+        Connection con = getConnection(true, context);
+        try {
+            return doGetUserIdentity(session, serviceId, accountId, con);
+        } finally {
+            provider.releaseReadConnection(context, con);
+        }
+    }
+
+    private String doGetUserIdentity(Session session, String serviceId, int accountId, Connection connection) throws OXException {
         int contextId = session.getContextId();
         int userId = session.getUserId();
-        final Context context = getContext(contextId);
-        boolean releaseConnection = false;
-        if (connection == null) {
-            connection = getConnection(true, context);
-            releaseConnection = true;
-        }
 
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -916,17 +889,11 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
             stmt.setString(3, serviceId);
             stmt.setInt(4, accountId);
             rs = stmt.executeQuery();
-            if (!rs.next()) {
-                return null;
-            }
-            return rs.getString(1);
-        } catch (final SQLException e) {
+            return rs.next() ? rs.getString(1) : null;
+        } catch (SQLException e) {
             throw OAuthExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
-            if (releaseConnection) {
-                provider.releaseReadConnection(context, connection);
-            }
         }
     }
 
@@ -940,7 +907,7 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
     private Context getContext(final int contextId) throws OXException {
         try {
             return contextService.getContext(contextId);
-        } catch (final OXException e) {
+        } catch (OXException e) {
             throw e;
         }
     }
@@ -1007,6 +974,18 @@ public class OAuthAccountStorageSQLImpl implements OAuthAccountStorage, SecretEn
         return service.encrypt(session, toEncrypt);
     }
 
+    private static String decryptToken(String encrypted, int accountId, Session session, SecretEncryptionService<PWUpdate> encryptionService) throws OXException {
+        return decrypt(true, encrypted, accountId, session, encryptionService);
+    }
+
+    private static String decryptSecret(String encrypted, int accountId, Session session, SecretEncryptionService<PWUpdate> encryptionService) throws OXException {
+        return decrypt(false, encrypted, accountId, session, encryptionService);
+    }
+
+    private static String decrypt(boolean token, String encrypted, int accountId, Session session, SecretEncryptionService<PWUpdate> encryptionService) throws OXException {
+        return encryptionService.decrypt(session, encrypted, new PWUpdate(token ? "accessToken" : "accessSecret", session.getContextId(), accountId));
+    }
+
     /**
      * {@link Setter}
      */
